/******************************************************************************
 * OpenLP - Open Source Lyrics Projection                                      *
 * --------------------------------------------------------------------------- *
 * Copyright (c) 2008-2017 OpenLP Developers                                   *
 * --------------------------------------------------------------------------- *
 * This program is free software; you can redistribute it and/or modify it     *
 * under the terms of the GNU General Public License as published by the Free  *
 * Software Foundation; version 2 of the License.                              *
 *                                                                             *
 * This program is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       *
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    *
 * more details.                                                               *
 *                                                                             *
 * You should have received a copy of the GNU General Public License along     *
 * with this program; if not, write to the Free Software Foundation, Inc., 59  *
 * Temple Place, Suite 330, Boston, MA 02111-1307 USA                          *
 ******************************************************************************/
window.OpenLP = {
    currentSlides: {},
    currentSlide: null,
    loadService: function (event) {
    $.getJSON(
      "/api/service/list",
      function (data, status) {
        for (idx in data.results.items) {
          idx = parseInt(idx, 10);
          if (data.results.items[idx]["selected"]) {
            // inserted for OBS control, I want to be able to read out the information
            OpenLP.currentTitle = data.results.items[idx]["title"];
            OpenLP.currentNotes = data.results.items[idx]["notes"];
            OpenLP.currentPlugin = data.results.items[idx]["plugin"];
            // see CSS file
            $("#currentslide").attr("data-plugin", OpenLP.currentPlugin);
            break;
          }
        }
        OpenLP.updateSlide();
      }
    );
  },
  loadSlides: function (event) {
    $.getJSON(
      "/api/v2/controller/live-item",
      function (data, status) {
        // OpenLP.currentSlides = data.results.slides;
        if(JSON.stringify(data.slides) == JSON.stringify(OpenLP.currentSlides)){
            return;
        }
        OpenLP.currentSlides = data.slides;
        OpenLP.pluginName = data.name;
        
        // $.each(data.results.slides, function(idx, slide) {
        $.each(data.slides, function(idx, slide) {
            OpenLP.currentSlide = idx;
        })
        OpenLP.loadService();
      }
    );
  },
  updateSlide: function() {
    // Show the current slide on top. Any trailing slides for the same verse
    // are shown too underneath in grey.
    // Then leave a blank line between following verses
    var slide = OpenLP.currentSlides[OpenLP.currentSlide];
    var text = "",
        verse = "",
        verse_location = "";
    var plugin = OpenLP.pluginName;
    // use title if available
    if (plugin == "bibles") {
        verse = slide["html"] || "";
        verse = verse.replace(/\n/g, " / ");
        verse_location = slide["title"];
        verse_location = verse_location.replace(/\n/g, " / ");
        $(".verse").html(verse);
        $(".verse-location").html(verse_location);
        $(".verse-display").css("display", "block");
        $("p", $(".message").css("display", "none")).html("");
        $(".image").css("display", "none").html("");
    } else if (plugin == "custom") {
        $("p", $(".message").css("display", "block")).html(slide["html"]);
        $(".verse").html(verse);
        $(".verse-location").html(verse_location);
        $(".verse-display").css("display", "none");
        $(".image").css("display", "none").html("");
    } else if (plugin == "images" || plugin == "presentations") {
        // use thumbnail if available
        $(".image").css("display", "block").html("<img src='" + slide["img"] + "' alt='thumbnail'>");
        $("p", $(".message").css("display", "none")).html("");
        $(".verse").html(verse);
        $(".verse-location").html(verse_location);
        $(".verse-display").css("display", "none");
        // use slide_notes if available
        if (slide["slide_notes"]) {
            $(".image").append('<br />' + slide["slide_notes"]);
        }
    } else {
    }

    OpenLP.obsRemote();
  },
  pollServer: function () {
      OpenLP.loadSlides();
      OpenLP.currentlyShowing = "slides";
  },
  obsRemote: function () {
    /*
    A list of all the information that could be useful to remote control OBS:
    pollServer() evaluates /api/poll, provides
    - OpenLP.currentlyShowing: blank|theme|display|slides
    loadService() evaluates /api/poll, provides
    - OpenLP.currentPlugin
    - OpenLP.currentTitle
    loadSlides() evaluates /api/controller/live/text, provides
    - OpenLP.currentSlides[OpenLP.currentSlide]["text"]
    - OpenLP.currentSlides[OpenLP.currentSlide]["html"]
    - OpenLP.currentSlides[OpenLP.currentSlide]["tag"]

    obs-websocket-js documentation at:
    https://github.com/haganbmj/obs-websocket-js

    obs-websocket controls can be found at:
    https://github.com/Palakis/obs-websocket/blob/4.x-current/docs/generated/protocol.md
    */

    OpenLP.obsHandler = new OBSWebSocket();
    OpenLP.obsHandler.connect({address: 'localhost:4444', password: ''}).then(() => {
      // Example 1a: use an item with the title "scenechange:altar" to switch to OBS scene "altar"
      if(preg = /scenechange:(.+)/i.exec(OpenLP.currentTitle)) {
        OpenLP.obsHandler.send('SetCurrentScene', {'scene-name': preg[1]});
      }
      // Example 1b: put "scenechange:altar" into the notes of an item
      if(preg = /scenechange:(.+)/i.exec(OpenLP.currentNotes)) {
        OpenLP.obsHandler.send('SetCurrentScene', {'scene-name': preg[1]});
      }
      // Example 2: toggle visibility of OBS scene item "lyrics",
      // depending on if the slide your showing is a song or not
      OpenLP.obsHandler.send('SetSceneItemProperties', {'item': 'lyrics', 'visible': (OpenLP.currentPlugin == "songs")});
    });
  }
}
$.ajaxSetup({ cache: false });
setInterval("OpenLP.pollServer();", 500);
OpenLP.pollServer();
